//
//  MainTableViewController.swift
//  TinyAnimations
//
//  Created by Michael Gazzola on 9/28/14.
//  Copyright (c) 2014 Michael Gazzola. All rights reserved.
//

import UIKit

struct AnimationStrings {
    static let kAnimationLabelBasicAnimations: String = "Basic Animations"
    static let kAnimationLabelKeyframeAnimations: String = "Keyframe Animations"
    
    static let kAnimationExampleTwoColor: String = "2-Color"
    static let kAnimationExampleTwoPoint: String = "2-Point"
    static let kAnimationExampleMultiColor: String = "Multicolor"
    static let kAnimationExampleMultiPoint: String = "Multi Point Position"
    static let kAnimationExampleBezierCurve: String = "Bezier Curve"
    static let kAnimationExampleSimpleRotation: String = "Simple 2D Rotation"
    static let kAnimationExample3DRotation: String = "3D Rotation"
    static let kAnimationExampleBlowUpSize: String = "Blow Up Size"
    static let kAnimationExampleCustom: String = "Custom"
}

final class MainTableViewController: UITableViewController {
    let kAnimationLabels: [String] = [AnimationStrings.kAnimationLabelBasicAnimations,
                                      AnimationStrings.kAnimationLabelKeyframeAnimations]
    let kSectionedContent: [String : [String]] = [
        AnimationStrings.kAnimationLabelBasicAnimations : [AnimationStrings.kAnimationExampleTwoColor,
                                                           AnimationStrings.kAnimationExampleTwoPoint,
                                                           AnimationStrings.kAnimationExampleSimpleRotation,
                                                           AnimationStrings.kAnimationExample3DRotation],
        AnimationStrings.kAnimationLabelKeyframeAnimations : [AnimationStrings.kAnimationExampleMultiColor,
                                                              AnimationStrings.kAnimationExampleMultiPoint,
                                                              AnimationStrings.kAnimationExampleBlowUpSize,
                                                              AnimationStrings.kAnimationExampleCustom,
                                                              AnimationStrings.kAnimationExampleBezierCurve]
    ]
    let kReuseIdentifier: String = "animationCell"
    
    override func viewDidLoad() {
        super.viewDidLoad()
    }
    
    func animationExampleForIndexPath(indexPath: NSIndexPath) -> String? {
        let section: String = self.kAnimationLabels[indexPath.section]
        if let sectionContent: [String] = self.kSectionedContent[section] {
            return sectionContent[indexPath.row]
        }
        return nil
    }
    
    // MARK: - Table view data source
    
    override func numberOfSectionsInTableView(tableView: UITableView) -> Int {
        return self.kAnimationLabels.count
    }
    
    override func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        let sectionLabel: String = self.kAnimationLabels[section]
        if let sectionContent: [String] = self.kSectionedContent[sectionLabel] {
            return sectionContent.count
        }
        return 0
    }
    
    override func tableView(tableView: UITableView, titleForHeaderInSection section: Int) -> String? {
        return self.kAnimationLabels[section]
    }
    
    override func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
        var cell = tableView.dequeueReusableCellWithIdentifier(self.kReuseIdentifier) as? UITableViewCell ??
            UITableViewCell(style: .Default, reuseIdentifier: self.kReuseIdentifier)
        cell.textLabel!.text = self.animationExampleForIndexPath(indexPath)
        cell.accessoryType = UITableViewCellAccessoryType.DisclosureIndicator
        return cell
    }
    
    override func tableView(tableView: UITableView, didSelectRowAtIndexPath indexPath: NSIndexPath) {
        if let animation: String = self.animationExampleForIndexPath(indexPath) {
            var viewController: UIViewController!
            switch (animation) {
            case AnimationStrings.kAnimationExampleTwoColor:
                viewController = TwoColorAnimationViewController()
                break
            case AnimationStrings.kAnimationExampleTwoPoint:
                viewController = TwoPointAnimationViewController()
                break
            case AnimationStrings.kAnimationExampleSimpleRotation:
                viewController = SimpleRotationAnimationViewController()
                break
            case AnimationStrings.kAnimationExample3DRotation:
                viewController = ThreeDimensionalRotationAnimationViewController()
                break
            case AnimationStrings.kAnimationExampleMultiColor:
                viewController = MulticolorAnimationViewController()
                break
            case AnimationStrings.kAnimationExampleMultiPoint:
                viewController = MultipointAnimationViewController()
                break
            case AnimationStrings.kAnimationExampleBezierCurve:
                viewController = BezierCurveAnimationViewController()
                break
            case AnimationStrings.kAnimationExampleBlowUpSize:
                viewController = BlowUpSizeAnimationViewController()
                break
            case AnimationStrings.kAnimationExampleCustom:
                viewController = CustomAnimationViewController()
                break
            default:
                break
            }
            if (viewController != nil) {
                self.navigationController?.pushViewController(viewController, animated: true)
            }
        }
    }
}
