//
//  BaseAnimationViewController.swift
//  TinyAnimations
//
//  Created by Michael Gazzola on 9/28/14.
//  Copyright (c) 2014 Michael Gazzola. All rights reserved.
//

import UIKit

class BaseAnimationViewController: UIViewController {

    private var animateButton: UIButton!
    internal var animateView: UIView!
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        let screenRect: CGRect = UIScreen.mainScreen().bounds
        self.view.backgroundColor = UIColor.whiteColor()
        
        self.animateButton = UIButton.buttonWithType(.System) as UIButton
        self.animateButton.setTitle("Animate!", forState: .Normal)
        self.animateButton.titleLabel?.font = UIFont.systemFontOfSize(20.0)
        self.animateButton.sizeToFit()
        self.animateButton.center = CGPoint(x: CGRectGetMidX(screenRect),
                                            y: CGRectGetMaxY(screenRect) - CGRectGetHeight(self.animateButton.frame))
        self.animateButton.addTarget(self, action: "performAnimation", forControlEvents: .TouchUpInside)
        
        var animateViewFrame: CGRect = CGRect(origin: CGPointZero,
                                              size: CGSize(width: CGRectGetWidth(screenRect) / 2.0,
                                                           height: CGRectGetHeight(screenRect) / 4.0))
        self.animateView = UIView(frame: animateViewFrame)
        self.animateView.center = CGPoint(x: CGRectGetMidX(screenRect),
                                          y: CGRectGetMidY(screenRect) - CGRectGetHeight(self.animateButton.frame))
        self.animateView.backgroundColor = UIColor.redColor()
        
        self.view.addSubview(self.animateButton)
        self.view.addSubview(self.animateView)
    }
    
    final internal func performAnimation() {
        self.animate(self.animateView)
    }
    
    func animate(view: UIView) {
        fatalError("animate() function not overridden!")
    }
    
}
